@@ -20,6 +20,7 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
 import six
+from six.moves import http_client as http
 import webob
 
 from glance.api import policy
@@ -49,8 +50,8 @@ class ImageMembersController(object):
 
     def _get_member_repo(self, req, image):
         try:
-            # For public images, a forbidden exception with message
-            # "Public images do not have members" is thrown.
+            # For public, private, and community images, a forbidden exception
+            # with message "Only shared images have members." is thrown.
             return self.gateway.get_member_repo(image, req.context)
         except exception.Forbidden as e:
             msg = (_("Error fetching members of image %(image_id)s: "
@@ -95,7 +96,9 @@ class ImageMembersController(object):
         :param req: the Request object coming from the wsgi layer
         :param image_id: the image identifier
         :param member_id: the member identifier
-        :retval The response body is a mapping of the following form::
+        :returns: The response body is a mapping of the following form
+
+        ::
 
             {'member_id': <MEMBER>,
              'image_id': <IMAGE>,
@@ -137,11 +140,13 @@ class ImageMembersController(object):
         :param req: the Request object coming from the wsgi layer
         :param image_id: the image identifier
         :param member_id: the member identifier
-        :retval The response body is a mapping of the following form::
+        :returns: The response body is a mapping of the following form
+
+        ::
 
             {'member_id': <MEMBER>,
              'image_id': <IMAGE>,
-             'status': <MEMBER_STATUS>
+             'status': <MEMBER_STATUS>,
              'created_at': ..,
              'updated_at': ..}
 
@@ -170,15 +175,18 @@ class ImageMembersController(object):
 
         :param req: the Request object coming from the wsgi layer
         :param image_id: The image identifier
-        :retval The response body is a mapping of the following form::
+        :returns: The response body is a mapping of the following form
+
+        ::
 
             {'members': [
                 {'member_id': <MEMBER>,
                  'image_id': <IMAGE>,
-                 'status': <MEMBER_STATUS>
+                 'status': <MEMBER_STATUS>,
                  'created_at': ..,
                  'updated_at': ..}, ..
             ]}
+
         """
         image = self._lookup_image(req, image_id)
         member_repo = self._get_member_repo(req, image)
@@ -198,13 +206,16 @@ class ImageMembersController(object):
 
         :param req: the Request object coming from the wsgi layer
         :param image_id: The image identifier
-        :retval The response body is a mapping of the following form::
+        :returns: The response body is a mapping of the following form
+
+        ::
 
             {'member_id': <MEMBER>,
              'image_id': <IMAGE>,
              'status': <MEMBER_STATUS>
              'created_at': ..,
              'updated_at': ..}
+
         """
         try:
             image = self._lookup_image(req, image_id)
@@ -224,7 +235,7 @@ class ImageMembersController(object):
         member = self._lookup_member(req, image, member_id)
         try:
             member_repo.remove(member)
-            return webob.Response(body='', status=204)
+            return webob.Response(body='', status=http.NO_CONTENT)
         except exception.Forbidden:
             msg = _("Not allowed to delete members for image %s.") % image_id
             LOG.warning(msg)
