@@ -38,18 +38,12 @@ from oslo_log import log as logging
 from glance.common import config
 from glance import scrubber
 
-# NOTE(jokke): As per the eventlet commit
-# b756447bab51046dfc6f1e0e299cc997ab343701 there's circular import happening
-# which can be solved making sure the hubs are properly and fully imported
-# before calling monkey_patch(). This is solved in eventlet 0.22.0 but we
-# need to address it before that is widely used around.
-eventlet.hubs.get_hub()
 eventlet.patcher.monkey_patch(all=False, socket=True, time=True, select=True,
                               thread=True, os=True)
 
 CONF = cfg.CONF
 logging.register_options(CONF)
-CONF.set_default(name='use_stderr', default=True, enforce_type=True)
+CONF.set_default(name='use_stderr', default=True)
 
 
 def main():
