@@ -14,7 +14,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import glance_store
-from oslo_log import log as logging
 
 from glance.api import authorization
 from glance.api import policy
@@ -28,9 +27,6 @@ import glance.notifier
 import glance.quota
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Gateway(object):
     def __init__(self, db_api=None, store_api=None, notifier=None,
                  policy_enforcer=None):
@@ -93,6 +89,20 @@ class Gateway(object):
 
         return authorized_image_repo
 
+    def get_member_repo(self, image, context):
+        image_member_repo = glance.db.ImageMemberRepo(
+            context, self.db_api, image)
+        store_image_repo = glance.location.ImageMemberRepoProxy(
+            image_member_repo, image, context, self.store_api)
+        policy_member_repo = policy.ImageMemberRepoProxy(
+            store_image_repo, image, context, self.policy)
+        notifier_member_repo = glance.notifier.ImageMemberRepoProxy(
+            policy_member_repo, image, context, self.notifier)
+        authorized_member_repo = authorization.ImageMemberRepoProxy(
+            notifier_member_repo, image, context)
+
+        return authorized_member_repo
+
     def get_task_factory(self, context):
         task_factory = glance.domain.TaskFactory()
         policy_task_factory = policy.TaskFactoryProxy(
