@@ -13,11 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import glance.cmd as glance_cmd
-
-
-glance_cmd.fix_greendns_ipv6()
-
 # See http://code.google.com/p/python-nose/issues/detail?id=373
 # The code below enables tests to work with i18n _() blocks
 import six.moves.builtins as __builtin__
@@ -33,10 +28,4 @@ logger.addHandler(hdlr)
 logger.setLevel(logging.DEBUG)
 
 import eventlet
-# NOTE(jokke): As per the eventlet commit
-# b756447bab51046dfc6f1e0e299cc997ab343701 there's circular import happening
-# which can be solved making sure the hubs are properly and fully imported
-# before calling monkey_patch(). This is solved in eventlet 0.22.0 but we
-# need to address it before that is widely used around.
-eventlet.hubs.get_hub()
 eventlet.patcher.monkey_patch()
