@@ -21,10 +21,6 @@ and Registry server, grabbing the logs of each, cleaning up pidfiles,
 and spinning down the servers.
 """
 
-# NOTE(rosmaita): mriedem says this is needed for importing from fixtures,
-# and he's right!
-from __future__ import absolute_import
-
 import atexit
 import datetime
 import errno
@@ -81,6 +77,9 @@ class Server(object):
         self.property_protection_file = ''
         self.enable_v1_api = True
         self.enable_v2_api = True
+        # TODO(rosmaita): remove in Queens when the option is removed
+        # also, don't forget to remove it from ApiServer.conf_base
+        self.enable_image_import = False
         self.enable_v1_registry = True
         self.enable_v2_registry = True
         self.needs_database = False
@@ -268,9 +267,9 @@ class Server(object):
         log = logging.getLogger(name)
         if not self.log_file or not os.path.exists(self.log_file):
             return
-        fptr = open(self.log_file, 'r')
-        for line in fptr:
-            log.info(line.strip())
+        with open(self.log_file, 'r') as fptr:
+            for line in fptr:
+                log.info(line.strip())
 
 
 class ApiServer(Server):
@@ -352,6 +351,7 @@ show_multiple_locations = %(show_multiple_locations)s
 user_storage_quota = %(user_storage_quota)s
 enable_v1_api = %(enable_v1_api)s
 enable_v2_api = %(enable_v2_api)s
+enable_image_import = %(enable_image_import)s
 lock_path = %(lock_path)s
 property_protection_file = %(property_protection_file)s
 property_protection_rule_format = %(property_protection_rule_format)s
@@ -607,6 +607,10 @@ class FunctionalTest(test_utils.BaseTestCase):
         self.api_protocol = 'http'
         self.api_port, api_sock = test_utils.get_unused_port_and_socket()
         self.registry_port, reg_sock = test_utils.get_unused_port_and_socket()
+        # NOTE: Scrubber is enabled by default for the functional tests.
+        # Please disbale it by explicitly setting 'self.include_scrubber' to
+        # False in the test SetUps that do not require Scrubber to run.
+        self.include_scrubber = True
 
         self.tracecmd = tracecmd_osmap.get(platform.system())
 
@@ -803,11 +807,11 @@ class FunctionalTest(test_utils.BaseTestCase):
 
         self.start_with_retry(self.api_server, 'api_port', 3, **kwargs)
 
-        exitcode, out, err = self.scrubber_daemon.start(**kwargs)
-
-        self.assertEqual(0, exitcode,
-                         "Failed to spin up the Scrubber daemon. "
-                         "Got: %s" % err)
+        if self.include_scrubber:
+            exitcode, out, err = self.scrubber_daemon.start(**kwargs)
+            self.assertEqual(0, exitcode,
+                             "Failed to spin up the Scrubber daemon. "
+                             "Got: %s" % err)
 
     def ping_server(self, port):
         """
@@ -900,7 +904,7 @@ class FunctionalTest(test_utils.BaseTestCase):
 
         return msg if expect_launch else None
 
-    def stop_server(self, server, name):
+    def stop_server(self, server):
         """
         Called to stop a single server in a normal fashion using the
         glance-control stop method to gracefully shut the server down.
@@ -921,9 +925,10 @@ class FunctionalTest(test_utils.BaseTestCase):
         """
 
         # Spin down the API and default registry server
-        self.stop_server(self.api_server, 'API server')
-        self.stop_server(self.registry_server, 'Registry server')
-        self.stop_server(self.scrubber_daemon, 'Scrubber daemon')
+        self.stop_server(self.api_server)
+        self.stop_server(self.registry_server)
+        if self.include_scrubber:
+            self.stop_server(self.scrubber_daemon)
 
         self._reset_database(self.registry_server.sql_connection)
 
