@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2010-2011 OpenStack Foundation
 # Copyright 2014 IBM Corp.
 # All Rights Reserved.
@@ -27,6 +28,7 @@ from oslo_concurrency import processutils
 from oslo_serialization import jsonutils
 import routes
 import six
+from six.moves import http_client as http
 import webob
 
 from glance.api.v1 import router as router_v1
@@ -66,7 +68,7 @@ class RequestTest(test_utils.BaseTestCase):
     def test_content_range(self):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Content-Range"] = 'bytes 10-99/*'
-        range_ = request.get_content_range()
+        range_ = request.get_range_from_request(120)
         self.assertEqual(10, range_.start)
         self.assertEqual(100, range_.stop)  # non-inclusive
         self.assertIsNone(range_.length)
@@ -74,8 +76,21 @@ class RequestTest(test_utils.BaseTestCase):
     def test_content_range_invalid(self):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Content-Range"] = 'bytes=0-99'
-        self.assertRaises(webob.exc.HTTPBadRequest,
-                          request.get_content_range)
+        self.assertRaises(webob.exc.HTTPRequestRangeNotSatisfiable,
+                          request.get_range_from_request, 120)
+
+    def test_range(self):
+        request = wsgi.Request.blank('/tests/123')
+        request.headers["Range"] = 'bytes=10-99'
+        range_ = request.get_range_from_request(120)
+        self.assertEqual(10, range_.start)
+        self.assertEqual(100, range_.end)  # non-inclusive
+
+    def test_range_invalid(self):
+        request = wsgi.Request.blank('/tests/123')
+        request.headers["Range"] = 'bytes=150-'
+        self.assertRaises(webob.exc.HTTPRequestRangeNotSatisfiable,
+                          request.get_range_from_request, 120)
 
     def test_content_type_missing(self):
         request = wsgi.Request.blank('/tests/123')
@@ -94,6 +109,23 @@ class RequestTest(test_utils.BaseTestCase):
         result = request.get_content_type(('application/json',))
         self.assertEqual("application/json", result)
 
+    def test_params(self):
+        if six.PY2:
+            expected = webob.multidict.NestedMultiDict({
+                'limit': '20', 'name':
+                    '\xd0\x9f\xd1\x80\xd0\xb8\xd0\xb2\xd0\xb5\xd1\x82',
+                'sort_key': 'name', 'sort_dir': 'asc'})
+        else:
+            expected = webob.multidict.NestedMultiDict({
+                'limit': '20', 'name': 'Привет', 'sort_key': 'name',
+                'sort_dir': 'asc'})
+
+        request = wsgi.Request.blank("/?limit=20&name=%D0%9F%D1%80%D0%B8"
+                                     "%D0%B2%D0%B5%D1%82&sort_key=name"
+                                     "&sort_dir=asc")
+        actual = request.params
+        self.assertEqual(expected, actual)
+
     def test_content_type_from_accept_xml(self):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Accept"] = "application/xml"
@@ -149,7 +181,7 @@ class RequestTest(test_utils.BaseTestCase):
         # best_match_language() returns None.
         self._set_expected_languages(all_locales=['it'])
 
-        req = wsgi.Request.blank('/', headers={'Accept-Language': 'zh'})
+        req = wsgi.Request.blank('/', headers={'Accept-Language': 'unknown'})
         self.assertIsNone(req.best_match_language())
 
     @mock.patch.object(webob.acceptparse.AcceptLanguage, 'best_match')
@@ -188,7 +220,7 @@ class RequestTest(test_utils.BaseTestCase):
                 req = webob.Request.blank(uri)
                 req.method = method
                 res = req.get_response(api)
-                self.assertEqual(405, res.status_int)
+                self.assertEqual(http.METHOD_NOT_ALLOWED, res.status_int)
 
         """Makes sure v2 unallowed methods return 405"""
         unallowed_methods = [
@@ -217,13 +249,13 @@ class RequestTest(test_utils.BaseTestCase):
                 req = webob.Request.blank(uri)
                 req.method = method
                 res = req.get_response(api)
-                self.assertEqual(405, res.status_int)
+                self.assertEqual(http.METHOD_NOT_ALLOWED, res.status_int)
 
         # Makes sure not implemented methods return 405
         req = webob.Request.blank('/schemas/image')
         req.method = 'NonexistentMethod'
         res = req.get_response(api)
-        self.assertEqual(405, res.status_int)
+        self.assertEqual(http.METHOD_NOT_ALLOWED, res.status_int)
 
 
 class ResourceTest(test_utils.BaseTestCase):
@@ -317,7 +349,7 @@ class ResourceTest(test_utils.BaseTestCase):
         response = resource.__call__(request)
 
         self.assertIsInstance(response, webob.exc.HTTPForbidden)
-        self.assertEqual(403, response.status_code)
+        self.assertEqual(http.FORBIDDEN, response.status_code)
 
     def test_call_raises_exception(self):
         class FakeController(object):
@@ -336,7 +368,7 @@ class ResourceTest(test_utils.BaseTestCase):
         response = resource.__call__(request)
 
         self.assertIsInstance(response, webob.exc.HTTPInternalServerError)
-        self.assertEqual(500, response.status_code)
+        self.assertEqual(http.INTERNAL_SERVER_ERROR, response.status_code)
 
     @mock.patch.object(wsgi, 'translate_exception')
     def test_resource_call_error_handle_localized(self,
@@ -433,7 +465,7 @@ class JSONResponseSerializerTest(test_utils.BaseTestCase):
         fixture = {"key": "value"}
         response = webob.Response()
         wsgi.JSONResponseSerializer().default(response, fixture)
-        self.assertEqual(200, response.status_int)
+        self.assertEqual(http.OK, response.status_int)
         content_types = [h for h in response.headerlist
                          if h[0] == 'Content-Type']
         self.assertEqual(1, len(content_types))
@@ -505,19 +537,32 @@ class JSONRequestDeserializerTest(test_utils.BaseTestCase):
         self.assertFalse(self._check_transfer_encoding(
                          transfer_encoding='invalid', content_length=0))
 
+    def test_has_body_invalid_transfer_encoding_no_content_len_and_body(self):
+        self.assertFalse(self._check_transfer_encoding(
+                         transfer_encoding='invalid', include_body=False))
+
+    def test_has_body_invalid_transfer_encoding_no_content_len_but_body(self):
+        self.assertTrue(self._check_transfer_encoding(
+                        transfer_encoding='invalid', include_body=True))
+
     def test_has_body_invalid_transfer_encoding_with_content_length(self):
         self.assertTrue(self._check_transfer_encoding(
                         transfer_encoding='invalid', content_length=5))
 
     def test_has_body_valid_transfer_encoding_with_content_length(self):
         self.assertTrue(self._check_transfer_encoding(
-                        transfer_encoding='chunked', content_length=0))
+                        transfer_encoding='chunked', content_length=1))
+
+    def test_has_body_valid_transfer_encoding_without_content_length(self):
+        self.assertTrue(self._check_transfer_encoding(
+                        transfer_encoding='chunked'))
 
     def _check_transfer_encoding(self, transfer_encoding=None,
-                                 content_length=None):
+                                 content_length=None, include_body=True):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
-        request.body = b'fake_body'
+        if include_body:
+            request.body = b'fake_body'
         request.headers['transfer-encoding'] = transfer_encoding
         if content_length is not None:
             request.headers['content-length'] = content_length
@@ -600,8 +645,7 @@ class TestHelpers(test_utils.BaseTestCase):
         """
         Verifies that data is the same after being passed through headers
         """
-        fixture = {'name': 'fake public image',
-                   'is_public': True,
+        fixture = {'is_public': True,
                    'deleted': False,
                    'name': None,
                    'size': 19,
