@@ -12,10 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-# NOTE(rosmaita): mriedem says this is needed for importing from fixtures,
-# and he's right!
-from __future__ import absolute_import
-
 import copy
 import os
 import sys
@@ -284,7 +280,7 @@ class FakeImageService(object):
         self.authtoken = authtoken
 
     def get_images(self):
-        if self.authtoken == 'livemastertoken':
+        if self.authtoken == 'livesourcetoken':
             return FAKEIMAGES_LIVEMASTER
         return FAKEIMAGES
 
@@ -355,7 +351,7 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
 
     def test_replication_size(self):
         options = moves.UserDict()
-        options.slavetoken = 'slavetoken'
+        options.targettoken = 'targettoken'
         args = ['localhost:9292']
 
         stdout = sys.stdout
@@ -410,7 +406,7 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
 
         options = moves.UserDict()
         options.chunksize = 4096
-        options.mastertoken = 'mastertoken'
+        options.sourcetoken = 'sourcetoken'
         options.metaonly = False
         args = ['localhost:9292', tempdir]
 
@@ -497,7 +493,7 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
         # Finally, we're ready to test
         options = moves.UserDict()
         options.dontreplicate = 'dontrepl dontreplabsent'
-        options.slavetoken = 'slavetoken'
+        options.targettoken = 'targettoken'
         args = ['localhost:9292', tempdir]
 
         orig_img_service = glance_replicator.get_image_service
@@ -526,8 +522,8 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
         options = moves.UserDict()
         options.chunksize = 4096
         options.dontreplicate = 'dontrepl dontreplabsent'
-        options.mastertoken = 'livemastertoken'
-        options.slavetoken = 'liveslavetoken'
+        options.sourcetoken = 'livesourcetoken'
+        options.targettoken = 'livetargettoken'
         options.metaonly = False
         args = ['localhost:9292', 'localhost:9393']
 
@@ -554,8 +550,8 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
         options = moves.UserDict()
         options.chunksize = 4096
         options.dontreplicate = 'dontrepl dontreplabsent'
-        options.mastertoken = 'livemastertoken'
-        options.slavetoken = 'liveslavetoken'
+        options.sourcetoken = 'livesourcetoken'
+        options.targettoken = 'livetargettoken'
         options.metaonly = False
         args = ['localhost:9292', 'localhost:9393']
 
