@@ -15,10 +15,6 @@
 
 """Common utilities used in testing"""
 
-# NOTE(rosmaita): mriedem says this is needed for importing from fixtures,
-# and he's right!
-from __future__ import absolute_import
-
 import errno
 import functools
 import os
@@ -631,9 +627,12 @@ class Httplib2WsgiAdapter(object):
 
     def request(self, uri, method="GET", body=None, headers=None):
         req = webob.Request.blank(uri, method=method, headers=headers)
-        req.body = body
+        if isinstance(body, str):
+            req.body = body.encode('utf-8')
+        else:
+            req.body = body
         resp = req.get_response(self.app)
-        return Httplib2WebobResponse(resp), resp.body
+        return Httplib2WebobResponse(resp), resp.body.decode('utf-8')
 
 
 class Httplib2WebobResponse(object):
@@ -688,3 +687,9 @@ def db_sync(version=None, engine=None):
 
     alembic_config = alembic_migrations.get_alembic_config(engine=engine)
     alembic_command.upgrade(alembic_config, version)
+
+
+def is_sqlite_version_prior_to(major, minor):
+    import sqlite3
+    tup = sqlite3.sqlite_version_info
+    return tup[0] < major or (tup[0] == major and tup[1] < minor)
